@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Amazon.py 10285 2017-09-11 01:55:49Z David $
+# $Id: Amazon.py 12868 2021-04-28 20:10:26Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,80 +11,72 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: David $
-# $Date: 2017-09-11 09:55:49 +0800 (週一, 11 九月 2017) $
-# $Revision: 10285 $
+# $Author: Lavender $
+# $Date: 2021-04-29 04:10:26 +0800 (週四, 29 四月 2021) $
+# $Revision: 12868 $
 
-import boto
+import boto3
 
 from django.conf import settings
 
 class SES(object):
     def __init__(self, AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY):
-
-        self.connection = boto.connect_ses(
-            AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY)
+        self.connection = boto3.client(
+            'ses', 
+            aws_access_key_id=AWS_ACCESS_KEY_ID, 
+            aws_secret_access_key=AWS_SECRET_ACCESS_KEY, 
+            region_name="us-east-1"
+        )
 
     def getIdentityNotificationAttributes(self, email):
-
-        values = self.connection._make_request(
-            "GetIdentityNotificationAttributes", {"Identities.member.1": email})
-        values = values['GetIdentityNotificationAttributesResponse']
-        values = values['GetIdentityNotificationAttributesResult']
-        values = values['NotificationAttributes']['entry']['value']
+        result = self.connection.get_identity_notification_attributes(Identities=[email,])
+        values = result.get("NotificationAttributes", {})
         return values
 
     def setIdentityNotificationTopic(self, notificationType, identity, topic):
-
-        self.connection._make_request(
-            "SetIdentityNotificationTopic", {
-                'NotificationType': notificationType,
-                'Identity': identity,
-                'SnsTopic': topic
-            }
+        result = ses.set_identity_notification_topic(
+            Identity=identity,
+            NotificationType=notificationType,
+            SnsTopic=topic
         )
 
     def getAllVerifiedSenders(self):
-
-        response = self.connection.list_verified_email_addresses()
-        response = response.get('ListVerifiedEmailAddressesResponse', {})
-        result = response.get('ListVerifiedEmailAddressesResult', {})
-        verifiedList = result.get('VerifiedEmailAddresses', [])
+        result = self.connection.list_identities(IdentityType='EmailAddress')
+        verifiedList = result.get('Identities', [])
         return verifiedList
 
     def verifyEmailAddress(self, email):
-
-        self.connection.verify_email_address(email)
+        result = self.connection.verify_email_identity(EmailAddress=email) 
+        return result.get("ResponseMetadata")
 
     def deleteVerifiedEmailAddress(self, email):
-
-        response = self.connection.delete_verified_email_address(email)
-        response = response.get('DeleteVerifiedEmailAddressResponse', {})
-        return response
+        result = self.connection.delete_identity(Identity=email)
+        return result.get("ResponseMetadata")
 
 class SNS(object):
     def __init__(self, AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY):
-
-        self.connection = boto.connect_sns(
-            AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY)
+        self.connection = boto3.client(
+            'sns', 
+            aws_access_key_id=AWS_ACCESS_KEY_ID, 
+            aws_secret_access_key=AWS_SECRET_ACCESS_KEY, 
+            region_name="us-east-1"
+        )
 
     def getAllTopicArns(self):
-        allTopics = self.connection.get_all_topics()
-        allTopics = allTopics['ListTopicsResponse']['ListTopicsResult']
+        allTopics = self.connection.list_topics()
         allTopics = allTopics['Topics']
         allTopics = [d['TopicArn'] for d in allTopics]
         return allTopics
 
     def createTopic(self, name):
-        topic = self.connection.create_topic(name)
-        topic = topic['CreateTopicResponse']['CreateTopicResult']
+        topic = self.connection.create_topic(Name=name)
         arn = topic['TopicArn']
         return arn
 
     def getAllSubscriptionsByTopic(self, topic):
-        response = self.connection.get_all_subscriptions_by_topic(topic)
-        response = response['ListSubscriptionsByTopicResponse']
-        response = response['ListSubscriptionsByTopicResult']
+        response = self.connection.list_subscriptions_by_topic(
+            TopicArn=topic,
+        )
         response = response['Subscriptions']
         return response
 
@@ -107,4 +99,8 @@ class SNS(object):
         else:
             protocol = 'http'
 
-        self.connection.subscribe(topic, protocol, link)
\ No newline at end of file
+        self.connection.subscribe(
+            TopicArn=topic, 
+            Protocol=protocol, 
+            Endpoint=link,
+        )
\ No newline at end of file
