@@ -15,7 +15,7 @@
 # $Date: 2013-05-16 06:52:28 +0000 (週四, 16 五月 2013) $
 # $Revision: 9166 $
 
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.http import HttpResponseRedirect
 
 def getIndex(request):
